=========
Messaging
=========

Messaging commands are available only if Abaqus/CAE is run interactively using the GUI.

Classes
-------

DataObject
~~~~~~~~~~

.. autoclass:: abaqus.Messaging.DataObject.DataObject
    :members:
    :special-members: __init__

    .. autoclasstoc::

MonitorMgr
~~~~~~~~~~

.. autoclass:: abaqus.Messaging.MonitorMgr.MonitorMgr
    :members:
    :special-members: __init__

    .. autoclasstoc::

